<?php

class DepartController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'depart';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $grids = $this->getGridData();
        $this->render('index', array('grids' => $grids));
    }

    public function actionAjaxList() {
        $grids = $this->getGridData($_POST['txtsearch']);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '') {
        $criteria = new CDbCriteria;
        $criteria->with = array(
            'faculty' => array(
                'together' => true,
            ),
        );
        $criteria->condition = "t.name LIKE :txtsearch or t.code LIKE :txtsearch or faculty.name LIKE :txtsearch";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 't.code asc';

        $count = Depart::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Depart::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionAjaxCreate() {
        $model = new Depart;
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxUpdate() {
        $id = $_POST['id'];
        $model = Depart::model()->findByPk($id);

        if (isset($_POST['save'])) {
            if ($id == '') {
                $model = new Depart;
            }

            $model->faculty_id = $_POST['faculty_id'];
            $model->code = $_POST['code'];
            $model->name = $_POST['name'];

            $data = $model->checkDuplicate($_POST['id'], $_POST['code']);
            if ($data['msg'] == '0') {
                $msg = 0;
                $msgText = '';
                if (!$model->save()) {
                    $msg = 1;
                    $msgText = array_shift($model->getErrors());
                }
                $data = array('msg' => $msg, 'msgText' => $msgText);
            }

            echo CJSON::encode($data);
            yii::app()->end();
        }
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxDelete() {
        $departId = (int) $_POST['id'];
        $msg = '0';
        $msgText = '';

        $user = User::model()->findByAttributes(array('depart_id' => $departId));
        if (isset($user->id)) {
            $msgText = "ไม่สามารถลบรายการได้เนื่องจากแผนกนี้ได้ถูกนำไปใช้กับข้อมูลผู้ใช้งานแล้ว";
            $msg = '1';
        } else {
            $row = Depart::model()->findByPk($departId);
            $row->delete();
        }
        $data['msg'] = $msg;
        $data['msgText'] = $msgText;
        echo CJSON::encode($data);
    }

}
