<?php

/**
 * This is the model class for table "tb_booking".
 *
 * The followings are the available columns in table 'tb_booking':
 * @property integer $id
 * @property string $docno
 * @property string $docdate
 * @property string $doctime
 * @property string $docref
 * @property integer $car_id
 * @property integer $status
 * @property integer $driver_id
 * @property string $start_date
 * @property string $end_date
 * @property string $working
 * @property string $address
 * @property string $tumbol
 * @property string $aumphur
 * @property string $province
 * @property integer $passenger_amount
 * @property string $passenger_name
 * @property integer $depart_id
 * @property string $person_name
 * @property string $tel
 * @property string $comment
 * @property integer $user_save_id
 * @property string $date_create
 * @property string $date_edit
 * @property string $read_date
 * @property string $approve_date
 * @property string $approve_comment
 * @property integer $save_status
 * @property integer $user_approve_id
 * @property double $car_rate
 * @property double $car_money
 * @property double $discount
 * @property string $date_return
 * @property string $date_return_ok
 * @property double $damage
 * @property string $return_comment
 * @property integer $user_return_id
 * @property string $file1
 * @property string $file1_name
 * @property string $file2
 * @property string $file2_name
 * @property string $time_expire
 */
class Booking extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_booking';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('car_id, status, driver_id, passenger_amount, depart_id, user_save_id, save_status, user_approve_id, user_return_id', 'numerical', 'integerOnly' => true),
            array('car_rate, car_money, discount, damage', 'numerical'),
            array('docno, docref', 'length', 'max' => 20),
            array('doctime', 'length', 'max' => 8),
            array('address, tumbol, aumphur, province, person_name, tel', 'length', 'max' => 100),
            array('file1, file2', 'length', 'max' => 50),
            array('docdate, start_date, end_date, working, passenger_name, comment, date_create, date_edit, read_date, approve_date, approve_comment, date_return, date_return_ok, return_comment, file1_name, file2_name, time_expire', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, docno, docdate, doctime, docref, car_id, status, driver_id, start_date, end_date, working, address, tumbol, aumphur, province, passenger_amount, passenger_name, depart_id, person_name, tel, comment, user_save_id, date_create, date_edit, read_date, approve_date, approve_comment, save_status, user_approve_id, car_rate, car_money, discount, date_return, date_return_ok, damage, return_comment, user_return_id, file1, file1_name, file2, file2_name, time_expire', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'driver' => array(self::BELONGS_TO, 'Driver', 'driver_id'),
            'userApprove' => array(self::BELONGS_TO, 'User', 'user_approve_id')
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'docno' => 'Docno',
            'docdate' => 'Docdate',
            'doctime' => 'Doctime',
            'docref' => 'Docref',
            'car_id' => 'Car',
            'status' => 'Status',
            'driver_id' => 'Driver',
            'start_date' => 'Start Date',
            'end_date' => 'End Date',
            'working' => 'Working',
            'address' => 'Address',
            'tumbol' => 'Tumbol',
            'aumphur' => 'Aumphur',
            'province' => 'Province',
            'passenger_amount' => 'Passenger Amount',
            'passenger_name' => 'Passenger Name',
            'depart_id' => 'Depart',
            'person_name' => 'Person Name',
            'tel' => 'Tel',
            'comment' => 'Comment',
            'user_save_id' => 'User Save',
            'date_create' => 'Date Create',
            'date_edit' => 'Date Edit',
            'read_date' => 'Read Date',
            'approve_date' => 'Approve Date',
            'approve_comment' => 'Approve Comment',
            'save_status' => 'Save Status',
            'user_approve_id' => 'User Approve',
            'car_rate' => 'Car Rate',
            'car_money' => 'Car Money',
            'discount' => 'Discount',
            'date_return' => 'Date Return',
            'date_return_ok' => 'Date Return Ok',
            'damage' => 'Damage',
            'return_comment' => 'Return Comment',
            'user_return_id' => 'User Return',
            'file1' => 'File1',
            'file1_name' => 'File1 Name',
            'file2' => 'File2',
            'file2_name' => 'File2 Name',
            'time_expire' => 'Time Expire',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('docno', $this->docno, true);
        $criteria->compare('docdate', $this->docdate, true);
        $criteria->compare('doctime', $this->doctime, true);
        $criteria->compare('docref', $this->docref, true);
        $criteria->compare('car_id', $this->car_id);
        $criteria->compare('status', $this->status);
        $criteria->compare('driver_id', $this->driver_id);
        $criteria->compare('start_date', $this->start_date, true);
        $criteria->compare('end_date', $this->end_date, true);
        $criteria->compare('working', $this->working, true);
        $criteria->compare('address', $this->address, true);
        $criteria->compare('tumbol', $this->tumbol, true);
        $criteria->compare('aumphur', $this->aumphur, true);
        $criteria->compare('province', $this->province, true);
        $criteria->compare('passenger_amount', $this->passenger_amount);
        $criteria->compare('passenger_name', $this->passenger_name, true);
        $criteria->compare('depart_id', $this->depart_id);
        $criteria->compare('person_name', $this->person_name, true);
        $criteria->compare('tel', $this->tel, true);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('user_save_id', $this->user_save_id);
        $criteria->compare('date_create', $this->date_create, true);
        $criteria->compare('date_edit', $this->date_edit, true);
        $criteria->compare('read_date', $this->read_date, true);
        $criteria->compare('approve_date', $this->approve_date, true);
        $criteria->compare('approve_comment', $this->approve_comment, true);
        $criteria->compare('save_status', $this->save_status);
        $criteria->compare('user_approve_id', $this->user_approve_id);
        $criteria->compare('car_rate', $this->car_rate);
        $criteria->compare('car_money', $this->car_money);
        $criteria->compare('discount', $this->discount);
        $criteria->compare('date_return', $this->date_return, true);
        $criteria->compare('date_return_ok', $this->date_return_ok, true);
        $criteria->compare('damage', $this->damage);
        $criteria->compare('return_comment', $this->return_comment, true);
        $criteria->compare('user_return_id', $this->user_return_id);
        $criteria->compare('file1', $this->file1, true);
        $criteria->compare('file1_name', $this->file1_name, true);
        $criteria->compare('file2', $this->file2, true);
        $criteria->compare('file2_name', $this->file2_name, true);
        $criteria->compare('time_expire', $this->time_expire, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Booking the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบรหัสซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('docno' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "เลขที่เอกสาร $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    /*
     * ข้อความสถานะ
     * $status = ค่าสถานะ
     * $des = เลือกแสดงค่าสถานะ
     */

    function getStatusText($status, $des = 0) {
        $ret = '';
        //(0=รออนุมัติ,1=เปิดอ่านแล้ว, 2=อนุมัติ, 3=ไม่อนุมัติ,4=ยกเลิก, 5=ส่งคืนรถแล้ว
        switch ($status) {
            case '9':
                $ret = 'อยู่ระหว่างทำรายการจอง';
                break;
            case '0':
                $ret = 'รออนุมัติ';
                break;
            case '1':
                if ($des == 0) {
                    $ret = 'เปิดอ่านแล้ว';
                } else {
                    $ret = 'รออนุมัติ';
                }
                break;
            case '2':
                if ($des == 0) {
                    $ret = 'อนุมัติ';
                } else {
                    $ret = '';
                }
                break;
            case '3':
                $ret = 'ไม่อนุมัติ';
                break;
            case '4':
                $ret = 'ยกเลิก';
                break;
            case '5':
                $ret = 'ส่งคืนรถแล้ว';
                break;
            case '6':
                $ret = 'รับคืนรถแล้ว';
                break;
        }
        return $ret;
    }

//แสดงสีสถานะการอนุมัติ
    function getLabelStatus($booking_id) {
        $model = self::model()->findByPk($booking_id);
        if ($model == null) {
            $status = '9';
        } else {
            $status = $model->status;
        }

        $ret = '';
//(9=อยู่ระหว่างทำรายการจอง, 0=รออนุมัติ,1=เปิดอ่านแล้ว, 2=อนุมัติ, 3=ไม่อนุมัติ,4=ยกเลิก, 5=ส่งคืนรถแล้ว)
        switch ($status) {
            case '9':
                $ret = '<span class="label label-warning">อยู่ระหว่างทำรายการจอง</span>';
                break;
            case '0':
                $ret = '<span class="label label-warning">รออนุมัติ</span>';
                break;
            case '1':
                //$ret = '<span class="label label-info">เปิดอ่านแล้ว</span>';
                $ret = '<span class="label label-info">Open</span>';
                break;
            case '2':
                $ret = '<span class="label label-primary">อนุมัติ</span>';
                break;
            case '3':
                $ret = '<span class="label label-danger">ไม่อนุมัติ</span>';
                break;
            case '4':
                $ret = '<span class="label label-default">ยกเลิก</span>';
                break;
            case '5':
                $ret = '<span class="label label-beforsuccess">ส่งคืนรถแล้ว</span>';
                break;
            case '6':
                $ret = '<span class="label label-success">รับคืนรถแล้ว</span>';
                break;
        }
        return $ret;
    }

//แสดงจำนวนรายการรออนุมัติ (ตามผู้อนัติประจำแผนก)
    public function countWating($user_approve_id) {
        $sql = "SELECT tb_booking.id FROM tb_booking ";
        $sql .= " INNER JOIN tb_userdepart ON tb_booking.depart_id = tb_userdepart.depart_id";
        $sql .= " WHERE tb_userdepart.user_id = '$user_approve_id'";
        $sql .= " AND (tb_booking.status='0' or tb_booking.status='1')";
        $count = Yii::app()->db->createCommand($sql)->execute();
        return $count;
    }

//แสดงจำนวนรายการส่งคืน ที่รอรับคืน (ตามผู้อนัติประจำแผนก)
    public function countReturn($user_approve_id) {
        $sql = "SELECT tb_booking.id FROM tb_booking ";
        $sql .= " INNER JOIN tb_userdepart ON tb_booking.depart_id = tb_userdepart.depart_id";
        $sql .= " WHERE tb_userdepart.user_id = '$user_approve_id'";
        $sql .= " AND (tb_booking.status='5')";
        $count = Yii::app()->db->createCommand($sql)->execute();
        return $count;
    }

//ตรวจสอบสถานะรถ วัน เวลาที่เลือก
    public function validateCarBusy($car_id, $start_date, $end_date) {
        $timeBefor = 0; //ต้องจองก่อนถึงเวลารถว่าง กี่นาที
        if ($timeBefor == 0) {
            $stime = '00:00:01';
            $etime = '-00:00:01';
        } else {
            $timeBefor--;
            $t = sprintf('%02d', $timeBefor);
            $stime = "-00:$t:00";
            $etime = "00:$t:00";
        }

        $sql = "select status from tb_booking where car_id='" . $car_id . "'";
        $sql .= " AND (";
        $sql .= " (ADDTIME(start_date, '$stime' ) between '$start_date' AND '$end_date')";
        $sql .= " OR (ADDTIME(end_date, '$etime') between '$start_date' AND '$end_date')";
        $sql .= " OR ('$start_date' between ADDTIME(start_date, '$stime' ) AND ADDTIME(end_date, '$etime'))";
        $sql .= " OR ('$end_date' between ADDTIME(start_date, '$stime' ) AND ADDTIME(end_date, '$etime'))";
        $sql .= ")";

        $row = Yii::app()->db->createCommand($sql)->queryRow();
        $status = '99';
        if (isset($row['status'])) {
            if ($row['status'] == '0' || $row['status'] == '1' || $row['status'] == '2' || $row['status'] == '9') {
                $status = $row['status'];
            }
        }

        return $status;
    }

    //ตรวจสอบว่าไฟล์แนบมีจริงหรือไม่
    public function getFileExist($id, $fieldName) {
        $model = self::model()->findByPk($id);
        $result = false;

        if ($model !== null) {
            if ($model->$fieldName != '') {
                //ตรวจสอบว่ามีภาพนี้อยู่จริงหรือไม่
                Yii::import('application.extensions.cfile.CFile');
                $cfile = new CFile();

                $dir = Yii::getPathOfAlias("webroot.fileupload.booking");
                $myfile = $cfile->set($dir . "/" . $model->$fieldName, true);
                if ($myfile->exists && $myfile->isfile) {
                    $result = true;
                }
            }
        }

        return $result;
    }

    //ลบไฟล์แนบ
    public function deleteFile($id, $fieldName = '') {
        Yii::import('application.extensions.cfile.CFile');
        $dir = Yii::getPathOfAlias("webroot.fileupload.booking");

        $model = self::model()->findByPk($id);
        if ($fieldName == '') {
            //ลบทั้งหมด
            for ($i = 1; $i < 3; $i++) {
                if ($this->getFileExist($id, "file$i")) {
                    $cfile = new CFile();

                    $fileNumber = "file$i";
                    $myfile = $cfile->set($dir . "/" . $model->$fileNumber, true);
                    $myfile->delete();
                }
            }
        } else {
            //ลบไฟล์ที่ระบุ
            if ($this->getFileExist($id, $fieldName)) {
                $cfile = new CFile();
                $myfile = $cfile->set($dir . "/" . $model->$fieldName, true);
                $myfile->delete();
            }
        }

        return true;
    }

    //ลบรายการที่ไม่บันทึกจอง (สถานะ 9) หากเกินเวลากำหนดจอง
    public function clearDraft() {
        $now = date('Y-m-d H:i:s');
        $sql = "delete from tb_booking where status='9' AND time_expire <= '$now'";
        Yii::app()->db->createCommand($sql)->execute();
    }

}
