<?php

/**
 * This is the model class for table "tb_car".
 *
 * The followings are the available columns in table 'tb_car':
 * @property integer $id
 * @property string $code
 * @property string $prov_code
 * @property string $prov_name
 * @property string $carno
 * @property integer $cartype_id
 * @property integer $brand_id
 * @property integer $oil_id
 * @property string $model
 * @property string $power
 * @property string $color
 * @property string $machine_no
 * @property string $machine_tank
 * @property integer $price
 * @property string $date_buy
 * @property string $date_in
 * @property string $date_f_code
 * @property string $date_e_code
 * @property string $date_f_cpi
 * @property string $date_e_cpi
 * @property string $date_f_insure
 * @property string $date_e_insure
 * @property integer $insurer_id
 * @property string $picture1
 * @property string $picture2
 * @property string $picture3
 * @property string $picture4
 * @property integer $status
 * @property string $comment
 * @property double $rate
 * @property integer $seats
 */
class Car extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_car';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('cartype_id, brand_id, oil_id, price, insurer_id, status, seats', 'numerical', 'integerOnly' => true),
            array('rate', 'numerical'),
            array('code, carno', 'length', 'max' => 20),
            array('prov_code', 'length', 'max' => 10),
            array('prov_name, color, machine_no, machine_tank', 'length', 'max' => 100),
            array('picture1, picture2, picture3, picture4', 'length', 'max' => 50),
            array('model, power, date_buy, date_in, date_f_code, date_e_code, date_f_cpi, date_e_cpi, date_f_insure, date_e_insure, comment', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, code, prov_code, prov_name, carno, cartype_id, brand_id, oil_id, model, power, color, machine_no, machine_tank, price, date_buy, date_in, date_f_code, date_e_code, date_f_cpi, date_e_cpi, date_f_insure, date_e_insure, insurer_id, picture1, picture2, picture3, picture4, status, comment, rate, seats', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'code' => 'Code',
            'prov_code' => 'Prov Code',
            'prov_name' => 'Prov Name',
            'carno' => 'Carno',
            'cartype_id' => 'Cartype',
            'brand_id' => 'Brand',
            'oil_id' => 'Oil',
            'model' => 'Model',
            'power' => 'Power',
            'color' => 'Color',
            'machine_no' => 'Machine No',
            'machine_tank' => 'Machine Tank',
            'price' => 'Price',
            'date_buy' => 'Date Buy',
            'date_in' => 'Date In',
            'date_f_code' => 'Date F Code',
            'date_e_code' => 'Date E Code',
            'date_f_cpi' => 'Date F Cpi',
            'date_e_cpi' => 'Date E Cpi',
            'date_f_insure' => 'Date F Insure',
            'date_e_insure' => 'Date E Insure',
            'insurer_id' => 'Insurer',
            'picture1' => 'Picture1',
            'picture2' => 'Picture2',
            'picture3' => 'Picture3',
            'picture4' => 'Picture4',
            'status' => 'Status',
            'comment' => 'Comment',
            'rate' => 'Rate',
            'seats' => 'Seats',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('code', $this->code, true);
        $criteria->compare('prov_code', $this->prov_code, true);
        $criteria->compare('prov_name', $this->prov_name, true);
        $criteria->compare('carno', $this->carno, true);
        $criteria->compare('cartype_id', $this->cartype_id);
        $criteria->compare('brand_id', $this->brand_id);
        $criteria->compare('oil_id', $this->oil_id);
        $criteria->compare('model', $this->model, true);
        $criteria->compare('power', $this->power, true);
        $criteria->compare('color', $this->color, true);
        $criteria->compare('machine_no', $this->machine_no, true);
        $criteria->compare('machine_tank', $this->machine_tank, true);
        $criteria->compare('price', $this->price);
        $criteria->compare('date_buy', $this->date_buy, true);
        $criteria->compare('date_in', $this->date_in, true);
        $criteria->compare('date_f_code', $this->date_f_code, true);
        $criteria->compare('date_e_code', $this->date_e_code, true);
        $criteria->compare('date_f_cpi', $this->date_f_cpi, true);
        $criteria->compare('date_e_cpi', $this->date_e_cpi, true);
        $criteria->compare('date_f_insure', $this->date_f_insure, true);
        $criteria->compare('date_e_insure', $this->date_e_insure, true);
        $criteria->compare('insurer_id', $this->insurer_id);
        $criteria->compare('picture1', $this->picture1, true);
        $criteria->compare('picture2', $this->picture2, true);
        $criteria->compare('picture3', $this->picture3, true);
        $criteria->compare('picture4', $this->picture4, true);
        $criteria->compare('status', $this->status);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('rate', $this->rate);
        $criteria->compare('seats', $this->seats);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Car the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบรหัสซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('code' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "ทะเบียนรถ $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    //แสดง path รูปภาพ
    public function getImagePath($id, $fieldName, $defaultImage = true) {
        $model = self::model()->findByPk($id);
        $pict = '';
        if ($defaultImage) {
            $pict = Yii::app()->request->baseUrl . "/images/noimage_640x480.jpg";
        }
        if ($model !== null) {
            if ($model->$fieldName != '') {
                //ตรวจสอบว่ามีภาพนี้อยู่จริงหรือไม่
                Yii::import('application.extensions.cfile.CFile');
                $cfile = new CFile();

                $dir = Yii::getPathOfAlias("webroot.fileupload.car");
                $myfile = $cfile->set($dir . "/" . $model->$fieldName, true);
                if ($myfile->exists && $myfile->isfile) {
                    $pict = Yii::app()->baseUrl . "/fileupload/car/" . $model->$fieldName . "?" . rand(1, 999);
                }
            }
        }

        return $pict;
    }

    //แสดงรายละเอียดรถ
    public function getCarDetail($car_id) {
        $sql = "SELECT tb_car.id, tb_car.`code`, tb_brand.`name` as brand_name, tb_car.model, ";
        $sql.= " tb_cartype.`name` as cartype_name, tb_oil.name as oil_name, tb_car.seats FROM tb_car ";
        $sql.= " LEFT JOIN tb_cartype ON tb_car.cartype_id = tb_cartype.id";
        $sql.= " LEFT JOIN tb_brand ON tb_car.brand_id = tb_brand.id";
        $sql.= " LEFT JOIN tb_oil ON tb_car.oil_id = tb_oil.id";
        $sql.= " WHERE tb_car.id = '$car_id'";
        $row = Yii::app()->db->createCommand($sql)->queryRow();
        return $row;
    }

    public function getStatusText($status_id) {
        $ret = '';
        switch ($status_id) {
            case '0':
                $ret = 'ปกติ';
                break;
            case '1':
                $ret = 'ซ่อมแซม';
                break;
            case '2':
                $ret = 'งดให้บริการชั่วคราว';
                break;
            case '3':
                $ret = 'ยกเลิกใช้';
                break;
        }

        return $ret;
    }

}
