<?php

/**
 * This is the model class for table "tb_company".
 *
 * The followings are the available columns in table 'tb_company':
 * @property integer $id
 * @property string $name
 * @property string $manager
 * @property string $address
 * @property string $province
 * @property string $tel
 * @property string $fax
 * @property string $en1
 * @property string $en2
 * @property string $en3
 * @property string $en4
 * @property string $en5
 * @property string $webheader
 * @property integer $booking_minute
 */
class Company extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'tb_company';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('booking_minute', 'numerical', 'integerOnly'=>true),
			array('name, manager, province, tel, fax, webheader', 'length', 'max'=>100),
			array('address, en1, en2, en3, en4, en5', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, name, manager, address, province, tel, fax, en1, en2, en3, en4, en5, webheader, booking_minute', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'manager' => 'Manager',
			'address' => 'Address',
			'province' => 'Province',
			'tel' => 'Tel',
			'fax' => 'Fax',
			'en1' => 'En1',
			'en2' => 'En2',
			'en3' => 'En3',
			'en4' => 'En4',
			'en5' => 'En5',
			'webheader' => 'Webheader',
			'booking_minute' => 'Booking Minute',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('manager',$this->manager,true);
		$criteria->compare('address',$this->address,true);
		$criteria->compare('province',$this->province,true);
		$criteria->compare('tel',$this->tel,true);
		$criteria->compare('fax',$this->fax,true);
		$criteria->compare('en1',$this->en1,true);
		$criteria->compare('en2',$this->en2,true);
		$criteria->compare('en3',$this->en3,true);
		$criteria->compare('en4',$this->en4,true);
		$criteria->compare('en5',$this->en5,true);
		$criteria->compare('webheader',$this->webheader,true);
		$criteria->compare('booking_minute',$this->booking_minute);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Company the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
