<?php

/**
 * This is the model class for table "tb_driver".
 *
 * The followings are the available columns in table 'tb_driver':
 * @property integer $id
 * @property string $code
 * @property string $title
 * @property string $firstname
 * @property string $surname
 * @property string $nickname
 * @property string $idcard
 * @property string $datef
 * @property string $datet
 * @property integer $status
 * @property string $comment
 * @property string $picture1
 * @property string $tel
 */
class Driver extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_driver';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('status', 'numerical', 'integerOnly' => true),
            array('code, title, nickname, idcard', 'length', 'max' => 20),
            array('firstname, surname, picture1, tel', 'length', 'max' => 50),
            array('datef, datet, comment', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, code, title, firstname, surname, nickname, idcard, datef, datet, status, comment, picture1, tel', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'code' => 'Code',
            'title' => 'Title',
            'firstname' => 'Firstname',
            'surname' => 'Surname',
            'nickname' => 'Nickname',
            'idcard' => 'Idcard',
            'datef' => 'Datef',
            'datet' => 'Datet',
            'status' => 'Status',
            'comment' => 'Comment',
            'picture1' => 'Picture1',
            'tel' => 'Tel',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('code', $this->code, true);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('firstname', $this->firstname, true);
        $criteria->compare('surname', $this->surname, true);
        $criteria->compare('nickname', $this->nickname, true);
        $criteria->compare('idcard', $this->idcard, true);
        $criteria->compare('datef', $this->datef, true);
        $criteria->compare('datet', $this->datet, true);
        $criteria->compare('status', $this->status);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('picture1', $this->picture1, true);
        $criteria->compare('tel', $this->tel, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Driver the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบรหัสซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('code' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "รหัส $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    //แสดง path รูปภาพ
    public function getImagePath($id, $defaultImage = true) {
        $model = self::model()->findByPk($id);
        $pict = '';
        if ($defaultImage) {
            $pict = Yii::app()->request->baseUrl . "/images/nophoto.jpg";
        }
        if ($model !== null) {
            if ($model->picture1 != '') {
                //ตรวจสอบว่ามีภาพนี้อยู่จริงหรือไม่
                Yii::import('application.extensions.cfile.CFile');
                $cfile = new CFile();

                $dir = Yii::getPathOfAlias("webroot.fileupload.driver");
                $myfile = $cfile->set($dir . "/" . $model->picture1, true);
                if ($myfile->exists && $myfile->isfile) {
                    $pict = Yii::app()->baseUrl . "/fileupload/driver/" . $model->picture1 . "?" . rand(1, 999);
                }
            }
        }

        return $pict;
    }

}
