<?php

/**
 * This is the model class for table "tb_userlog".
 *
 * The followings are the available columns in table 'tb_userlog':
 * @property integer $id
 * @property integer $user_id
 * @property string $user_name
 * @property string $indate
 * @property string $intime
 * @property string $code
 * @property string $description
 * @property string $ip
 * @property string $user_agent
 */
class Userlog extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_userlog';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('user_id, user_name, indate, intime, description, ip', 'required'),
            array('user_id', 'numerical', 'integerOnly' => true),
            array('user_name', 'length', 'max' => 100),
            array('intime', 'length', 'max' => 10),
            array('code', 'length', 'max' => 5),
            array('ip', 'length', 'max' => 50),
            array('user_agent', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, user_id, user_name, indate, intime, code, description, ip, user_agent', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'user_id' => 'User',
            'user_name' => 'User Name',
            'indate' => 'Indate',
            'intime' => 'Intime',
            'code' => 'Code',
            'description' => 'Description',
            'ip' => 'Ip',
            'user_agent' => 'User Agent',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('user_id', $this->user_id);
        $criteria->compare('user_name', $this->user_name, true);
        $criteria->compare('indate', $this->indate, true);
        $criteria->compare('intime', $this->intime, true);
        $criteria->compare('code', $this->code, true);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('ip', $this->ip, true);
        $criteria->compare('user_agent', $this->user_agent, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Userlog the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public static function saveLog($code, $description) {
        /*
         * 001 = เข้าสู่ระบบ
         * 002 = จองใช้รถ
         */
        $model = new Userlog;
        $model->user_id = Yii::app()->user->id;
        $model->user_name = Yii::app()->user->name;
        $model->indate = date('Y-m-d');
        $model->intime = date('H:i:s');
        $model->code = $code;
        $model->description = $description;
        $model->ip = Yii::app()->request->userHostAddress;
        $model->user_agent = Yii::app()->request->userAgent;

        if (!$model->save()) {
            print_r($model->getErrors());
        }
    }

}
